about summary refs log tree commit diff
path: root/sysdeps/powerpc/powerpc64/power6
diff options
context:
space:
mode:
authorOndřej Bílka <neleai@seznam.cz>2013-08-30 18:09:30 +0200
committerOndřej Bílka <neleai@seznam.cz>2013-08-30 18:10:31 +0200
commitf24a6d086b96a65a73c68ecf349b03321cb03720 (patch)
tree823c4db1322b11c81ba5ce05d77adbf4afbdbbc8 /sysdeps/powerpc/powerpc64/power6
parent382466e04e347d3b3fa221897efb8f4cdc239105 (diff)
downloadglibc-f24a6d086b96a65a73c68ecf349b03321cb03720.tar.gz
glibc-f24a6d086b96a65a73c68ecf349b03321cb03720.tar.xz
glibc-f24a6d086b96a65a73c68ecf349b03321cb03720.zip
Fix then/than typos.
Diffstat (limited to 'sysdeps/powerpc/powerpc64/power6')
-rw-r--r--sysdeps/powerpc/powerpc64/power6/memcpy.S10
-rw-r--r--sysdeps/powerpc/powerpc64/power6/memset.S4
2 files changed, 7 insertions, 7 deletions
diff --git a/sysdeps/powerpc/powerpc64/power6/memset.S b/sysdeps/powerpc/powerpc64/power6/memset.S
index 541a45fd36..3e8ae2d25e 100644
--- a/sysdeps/powerpc/powerpc64/power6/memset.S
+++ b/sysdeps/powerpc/powerpc64/power6/memset.S
@@ -110,7 +110,7 @@ L(caligned):
    boundary may not be at cache line (128-byte) boundary.  */
 L(nzloopstart):
 /* memset in 32-byte chunks until we get to a cache line boundary.
-   If rLEN is less then the distance to the next cache-line boundary use
+   If rLEN is less than the distance to the next cache-line boundary use
    cacheAligned1 code to finish the tail.  */
 	cmpldi	cr1,rLEN,128
 
@@ -186,7 +186,7 @@ L(nzCacheAligned128):
    block zero instruction. */
 L(zloopstart):
 /* memset in 32-byte chunks until we get to a cache line boundary.
-   If rLEN is less then the distance to the next cache-line boundary use
+   If rLEN is less than the distance to the next cache-line boundary use
    cacheAligned1 code to finish the tail.  */
 	cmpldi	cr1,rLEN,128
 	beq	L(medium)
diff --git a/sysdeps/powerpc/powerpc64/power6/memcpy.S b/sysdeps/powerpc/powerpc64/power6/memcpy.S
index db29e2b065..d6d242d293 100644
--- a/sysdeps/powerpc/powerpc64/power6/memcpy.S
+++ b/sysdeps/powerpc/powerpc64/power6/memcpy.S
@@ -450,7 +450,7 @@ L(dus_tail16): /* Move 16 bytes.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail16p8):  /* less then 8 bytes left.  */
+L(dus_tail16p8):  /* less than 8 bytes left.  */
     beq   cr1,L(dus_tailX) /* exactly 16 bytes, early exit.  */
     cmpldi	cr1,10,20
     bf    29,L(dus_tail16p2)
@@ -464,7 +464,7 @@ L(dus_tail16p8):  /* less then 8 bytes left.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail16p4):  /* less then 4 bytes left.  */
+L(dus_tail16p4):  /* less than 4 bytes left.  */
     addi  12,12,24
     addi  3,3,24
     bgt   cr0,L(dus_tail2)
@@ -472,7 +472,7 @@ L(dus_tail16p4):  /* less then 4 bytes left.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail16p2):  /* 16 bytes moved, less then 4 bytes left.  */
+L(dus_tail16p2):  /* 16 bytes moved, less than 4 bytes left.  */
     addi  12,12,16
     addi  3,3,16
     b     L(dus_tail2)
@@ -497,7 +497,7 @@ L(dus_tail8):  /* Move 8 bytes.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail8p4):  /* less then 4 bytes left.  */
+L(dus_tail8p4):  /* less than 4 bytes left.  */
     addi  12,12,8
     addi  3,3,8
     bgt   cr1,L(dus_tail2)
@@ -508,7 +508,7 @@ L(dus_tail8p4):  /* less then 4 bytes left.  */
     .align  4
 L(dus_tail4):  /* Move 4 bytes.  */
 /*  r6 already loaded speculatively.  If we are here we know there is
-    more then 4 bytes left.  So there is no need to test.  */
+    more than 4 bytes left.  So there is no need to test.  */
     addi  12,12,4
     stw   6,0(3)
     addi  3,3,4